@@ -771,7 +771,8 @@ class DataframeFunctions(scrapi_base.ScrapiBase):
         Returns:
           entity_pb: the new entity protobuf object
         """
-
+        if not meta:
+            meta = {}
         entity_obj = {}
         entity_obj["display_name"] = display_name
         entity_obj["kind"] = meta.get("kind", 1)
@@ -795,7 +796,9 @@ class DataframeFunctions(scrapi_base.ScrapiBase):
         return entity_pb
 
     def bulk_create_entity_from_dataframe(
-        self, agent_id, entities_df, update_flag=False, rate_limiter=5
+        self, agent_id, entities_df, update_flag=False,
+        language_code: str = None, rate_limiter=5,
+
     ):
         """Bulk create entities from a dataframe.
 
@@ -805,10 +808,12 @@ class DataframeFunctions(scrapi_base.ScrapiBase):
           entities_df: dataframe of bulk entities;
             required columns: display_name, value, synonyms
           update_flag: True to update_flag the entities in the agent
+          language_code: Language code of the intents being uploaded. Ref:
+            https://cloud.google.com/dialogflow/cx/docs/reference/language
           rate_limiter: seconds to sleep between operations.
 
         Returns:
-          new_entities: dictionary with entity display names as keys and the
+          custom_entities: dictionary with entity display names as keys and the
             new entity protobufs as values
         """
 
@@ -839,7 +844,9 @@ class DataframeFunctions(scrapi_base.ScrapiBase):
 
             if update_flag:
                 self.entities.create_entity_type(
-                    agent_id=agent_id, obj=new_entity
+                    agent_id=agent_id,
+                    obj=new_entity,
+                    language_code=language_code,
                 )
                 time.sleep(rate_limiter)
 
@@ -849,6 +856,65 @@ class DataframeFunctions(scrapi_base.ScrapiBase):
             )
         return custom_entities
 
+    def bulk_update_entity_from_dataframe(
+        self, entities_df, update_flag=False, language_code=None,
+        rate_limiter=5
+    ):
+        """Bulk updates entities from a dataframe.
+
+        Args:
+          agent_id: name parameter of the agent to update_flag - full path to
+            agent
+          entities_df: dataframe of bulk entities;
+            required columns: display_name, value, synonyms
+          update_flag: True to update_flag the entities in the agent
+          language_code: Language code of the intents being uploaded. Ref:
+          https://cloud.google.com/dialogflow/cx/docs/reference/language
+          rate_limiter: seconds to sleep between operations.
+
+        Returns:
+          custom_entities: dictionary with entity display names as keys and the
+            new entity protobufs as values
+        """
+        if "meta" in entities_df.columns:
+            meta = (
+                entities_df.copy()[["display_name", "meta"]]
+                .drop_duplicates()
+                .reset_index()
+            )
+
+        i, custom_entities = 0, {}
+        for entity in list(set(entities_df["display_name"])):
+            one_entity = entities_df[entities_df["display_name"] == entity]
+            if "meta" in locals():
+                meta_ = meta[meta["display_name"] == entity]["meta"].iloc[0]
+                meta_ = json.loads(meta_)
+                new_entity = self.create_entity_from_dataframe(
+                    display_name=entity, entity_df=one_entity, meta=meta
+                )
+
+            else:
+                new_entity = self.create_entity_from_dataframe(
+                    display_name=entity, entity_df=one_entity
+                )
+
+            custom_entities[entity] = new_entity
+            i += 1
+            entity_type_id = one_entity["name"].max()
+
+            if update_flag:
+                self.entities.update_entity_type(
+                    entity_type_id, new_entity, language_code
+                )
+                time.sleep(rate_limiter)
+
+            self.progress_bar(
+                i, len(list(set(
+                    entities_df["display_name"]))), type_="entities"
+            )
+
+        return custom_entities
+
     def create_transition_route_from_dataframe(self, route_df):
         """Create transition route.
 
